@@ -1,5 +1,5 @@
 /***************************************************************************
-                              fractionringwidget.cpp
+                              TaskColors.h
                              -------------------
     begin                : 2009/08/10
     copyright            : (C) 2008 by Danilo Balzaque
@@ -26,7 +26,7 @@
 class TaskColors : public QWidget, public Ui::TaskColorsBase
 {
 public:
-    TaskColors(QWidget * parent) : QWidget(parent) {
+    explicit TaskColors(QWidget * parent) : QWidget(parent) {
         setupUi(this);
     }
 };
